@@ -2,6 +2,7 @@ import uuid
 from unittest import mock
 
 import pytest
+from django.core import validators
 from django.db import models
 from django.db.models import fields
 from django.urls import path, re_path
@@ -23,6 +24,7 @@ from drf_spectacular.utils import (
 )
 from drf_spectacular.validation import validate_schema
 from tests import generate_schema, get_request_schema, get_response_schema
+from tests.models import SimpleModel, SimpleSerializer
 
 
 def test_primary_key_read_only_queryset_not_found(no_warnings):
@@ -835,6 +837,29 @@ def test_auto_schema_and_extend_parameters(no_warnings):
     assert parameters[2]['name'] == 'id'
 
 
+def test_manually_set_auto_schema_with_extend_schema(no_warnings):
+    class CustomSchema(AutoSchema):
+        def get_override_parameters(self):
+            if self.method.lower() == "delete":
+                return [OpenApiParameter("custom_param", str)]
+            return super().get_override_parameters()
+
+    @extend_schema_view(
+        list=extend_schema(summary="list summary"),
+        destroy=extend_schema(summary="delete summary"),
+    )
+    class XViewSet(mixins.ListModelMixin, mixins.DestroyModelMixin, viewsets.ViewSet):
+        queryset = SimpleModel.objects.all()
+        serializer_class = SimpleSerializer
+        schema = CustomSchema()
+
+    schema = generate_schema('x', XViewSet)
+    assert schema['paths']['/x/']['get']['summary'] == 'list summary'
+    assert schema['paths']['/x/{id}/']['delete']['summary'] == 'delete summary'
+    assert schema['paths']['/x/{id}/']['delete']['parameters'][0]['name'] == 'custom_param'
+    assert schema['paths']['/x/{id}/']['delete']['parameters'][1]['name'] == 'id'
+
+
 def test_list_serializer_with_field_child():
     class XSerializer(serializers.Serializer):
         field = serializers.ListSerializer(child=serializers.IntegerField())
@@ -946,40 +971,24 @@ def test_camelize_names(no_warnings):
 
 
 def test_mocked_request_with_get_queryset_get_serializer_class(no_warnings):
-    class M4(models.Model):
-        pass
-
-    class XSerializer(serializers.ModelSerializer):
-        class Meta:
-            fields = '__all__'
-            model = M4
-
     class XViewset(viewsets.ReadOnlyModelViewSet):
         def get_serializer_class(self):
             assert not self.request.user.is_authenticated
             assert self.action in ['retrieve', 'list']
-            return XSerializer
+            return SimpleSerializer
 
         def get_queryset(self):
             assert not self.request.user.is_authenticated
             assert self.request.method == 'GET'
-            return M4.objects.none()
+            return SimpleModel.objects.none()
 
     generate_schema('x', XViewset)
 
 
 def test_queryset_filter_and_ordering_only_on_list(no_warnings):
-    class M5(models.Model):
-        pass
-
-    class XSerializer(serializers.ModelSerializer):
-        class Meta:
-            fields = '__all__'
-            model = M5
-
     class XViewset(viewsets.ReadOnlyModelViewSet):
-        queryset = M5.objects.all()
-        serializer_class = XSerializer
+        queryset = SimpleModel.objects.none()
+        serializer_class = SimpleSerializer
         filter_backends = (filters.SearchFilter, filters.OrderingFilter)
 
     schema = generate_schema('x', XViewset)
@@ -995,17 +1004,9 @@ def test_queryset_filter_and_ordering_only_on_list(no_warnings):
 
 
 def test_pagination(no_warnings):
-    class M6(models.Model):
-        pass
-
-    class XSerializer(serializers.ModelSerializer):
-        class Meta:
-            fields = '__all__'
-            model = M6
-
     class XViewset(viewsets.ReadOnlyModelViewSet):
-        queryset = M6.objects.all()
-        serializer_class = XSerializer
+        queryset = SimpleModel.objects.none()
+        serializer_class = SimpleSerializer
         pagination_class = pagination.LimitOffsetPagination
 
     schema = generate_schema('x', XViewset)
@@ -1022,29 +1023,27 @@ def test_pagination(no_warnings):
     assert list_parameters[0]['name'] == 'id'
 
     # substituted component on list
-    assert 'X' in schema['components']['schemas']
-    assert 'PaginatedXList' in schema['components']['schemas']
-    substitution = schema['components']['schemas']['PaginatedXList']
+    assert 'Simple' in schema['components']['schemas']
+    assert 'PaginatedSimpleList' in schema['components']['schemas']
+    substitution = schema['components']['schemas']['PaginatedSimpleList']
     assert substitution['type'] == 'object'
-    assert substitution['properties']['results']['items']['$ref'] == '#/components/schemas/X'
+    assert substitution['properties']['results']['items']['$ref'] == '#/components/schemas/Simple'
 
 
 def test_pagination_reusage(no_warnings):
-    class M7(models.Model):
-        pass
-
-    class XSerializer(serializers.ModelSerializer):
-        class Meta:
-            fields = '__all__'
-            model = M7
 
     class XViewset(viewsets.ReadOnlyModelViewSet):
-        queryset = M7.objects.all()
-        serializer_class = XSerializer
+        queryset = SimpleModel.objects.all()
+        serializer_class = SimpleSerializer
         pagination_class = pagination.LimitOffsetPagination
 
+        @extend_schema(responses={'200': SimpleSerializer(many=True)})
+        @action(methods=['GET'], detail=False)
+        def custom_action(self):
+            pass  # pragma: no cover
+
     class YViewset(XViewset):
-        serializer_class = XSerializer
+        serializer_class = SimpleSerializer
 
     router = routers.SimpleRouter()
     router.register('x', XViewset, basename='x')
@@ -1142,22 +1141,14 @@ def test_string_response_variations(no_warnings, responses):
 
 
 def test_exclude_discovered_parameter(no_warnings):
-    class M8(models.Model):
-        pass
-
-    class XSerializer(serializers.ModelSerializer):
-        class Meta:
-            fields = '__all__'
-            model = M8
-
     @extend_schema_view(list=extend_schema(parameters=[
         # keep 'offset', remove 'limit', and add 'random'
         OpenApiParameter('limit', exclude=True),
         OpenApiParameter('random', bool),
     ]))
     class XViewset(viewsets.ReadOnlyModelViewSet):
-        queryset = M8.objects.all()
-        serializer_class = XSerializer
+        queryset = SimpleModel.objects.all()
+        serializer_class = SimpleSerializer
         pagination_class = pagination.LimitOffsetPagination
 
     schema = generate_schema('x', XViewset)
@@ -1165,3 +1156,91 @@ def test_exclude_discovered_parameter(no_warnings):
     assert len(parameters) == 2
     assert parameters[0]['name'] == 'offset'
     assert parameters[1]['name'] == 'random'
+
+
+def test_manual_decimal_validator():
+    # manually test this validator as it is not part of the default workflow
+    class XSerializer(serializers.Serializer):
+        field = serializers.CharField(
+            validators=[validators.DecimalValidator(max_digits=4, decimal_places=2)]
+        )
+
+    @extend_schema(request=XSerializer, responses=XSerializer)
+    @api_view(['POST'])
+    def view_func(request, format=None):
+        pass  # pragma: no cover
+
+    schema = generate_schema('x', view_function=view_func)
+    field = schema['components']['schemas']['X']['properties']['field']
+    assert field['maximum'] == 100
+    assert field['minimum'] == -100
+
+
+def test_non_supported_http_verbs(no_warnings):
+    HTTP_METHODS = [
+        'GET',
+        'HEAD',
+        'POST',
+        'PUT',
+        'DELETE',
+        'CONNECT',
+        'OPTIONS',
+        'TRACE',
+        'PATCH'
+    ]
+    for x in HTTP_METHODS:
+        @extend_schema(request=int, responses=int)
+        @api_view([x])
+        def view_func(request, format=None):
+            pass  # pragma: no cover
+
+        generate_schema('x', view_function=view_func)
+
+
+def test_nested_ro_serializer_has_required_fields_on_patch(no_warnings):
+    # issue #249 raised a disparity problem between serializer name
+    # generation and the actual serializer construction on PATCH.
+    class XSerializer(serializers.Serializer):
+        field = serializers.CharField()
+
+    class YSerializer(serializers.Serializer):
+        x_field = XSerializer(read_only=True)
+
+    class YViewSet(viewsets.GenericViewSet):
+        serializer_class = YSerializer
+        queryset = SimpleModel.objects.all()
+
+        def partial_update(self, request, *args, **kwargs):
+            pass  # pragma: no cover
+
+    schema = generate_schema('x', YViewSet)
+    assert len(schema['components']['schemas']) == 3
+    assert 'Y' in schema['components']['schemas']
+    assert 'PatchedY' in schema['components']['schemas']
+    assert 'required' in schema['components']['schemas']['X']
+
+
+@pytest.mark.parametrize('path', [
+    r'x/(?P<related_field>[0-9a-f-]{36})/',
+    r'x/<related_field>/',
+])
+def test_path_param_from_related_model_pk_without_primary_key_true(no_warnings, path):
+    class M3(models.Model):
+        related_field = models.ForeignKey(SimpleModel, on_delete=models.PROTECT, editable=False)
+        many_related = models.ManyToManyField(SimpleModel)
+
+    class M3Serializer(serializers.ModelSerializer):
+        class Meta:
+            fields = '__all__'
+            model = M3
+
+    class XViewset(viewsets.ModelViewSet):
+        serializer_class = M3Serializer
+        queryset = M3.objects.none()
+
+    router = routers.SimpleRouter()
+    router.register(path, XViewset)
+
+    schema = SchemaGenerator(patterns=router.urls).get_schema(request=None, public=True)
+    assert '/x/{related_field}/' in schema['paths']
+    assert '/x/{related_field}/{id}/' in schema['paths']
